@@ -44,7 +44,7 @@
 
 #include "config.h"
 
-static Lum::AppInfo info;
+static Lum::Def::AppInfo info;
 
 class MainDialog : public Lum::Dialog
 {
